EXPORTS
	?CmdSimSecurityCheckNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 1 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdSimSecurityCheckNewL(void)
	?CmdCoopSysSelfTestNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 2 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdCoopSysSelfTestNewL(void)
	?CmdCcoopSysPerformRfsActionsNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 3 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdCcoopSysPerformRfsActionsNewL(void)
	?CmdActivateRfForEmergencyCallNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 4 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdActivateRfForEmergencyCallNewL(void)
	?CmdCoopSysPerformRestartActionsNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 5 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdCoopSysPerformRestartActionsNewL(void)
	?CmdDeactivateRfForEmergencyCallNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 6 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdDeactivateRfForEmergencyCallNewL(void)
	?CmdCcoopSysPerformShutdownActionsNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 7 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdCcoopSysPerformShutdownActionsNewL(void)
	?CmdCoopSysStateChangeNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 8 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdCoopSysStateChangeNewL(void)
	?CmdPublishStartupModeNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 9 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdPublishStartupModeNewL(void)
	?CmdPublishSimOwnedAndChangedNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 10 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdPublishSimOwnedAndChangedNewL(void)
	?CmdDeviceSecurityCheckNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 11 NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdDeviceSecurityCheckNewL(void)
	?CmdValidateRTCNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 12  NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdValidateRTCNewL(void)
	?CmdCheckUserDriveNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 13  NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdCheckUserDriveNewL(void)
	?CmdInitRamDriveNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 14  NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdInitRamDriveNewL(void)
	?CmdDeleteTempFilesNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 15  NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdDeleteTempFilesNewL(void)
	?CmdClearStartupReasonNewL@SsmCustomCmdFactory@@SAPAVMSsmCustomCommand@@XZ @ 16  NONAME ; class MSsmCustomCommand * SsmCustomCmdFactory::CmdClearStartupReasonNewL(void)
